<?php

namespace Drupal\navigation_blocks;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Link;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Routing\CurrentRouteMatch;

/**
 * Provides a 'BackButtonBlockBase' class, which contains the CurrentRouteMatch
 * service and sets the route cache context.
 */
abstract class BackButtonBlockBase extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * CurrentRouteMatch service.
   *
   * @var \Drupal\Core\Routing\CurrentRouteMatch
   */
  protected $currentRouteMatch;
  /**
   * Constructs a new BackButtonBlockBase object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param string $plugin_definition
   *   The plugin implementation definition.
   * @param CurrentRouteMatch $current_route_match
   *   The CurrentRouteMatch service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, CurrentRouteMatch $current_route_match) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->currentRouteMatch = $current_route_match;
  }
  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static($configuration, $plugin_id, $plugin_definition, $container->get('current_route_match'));
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheContexts() {
    $cacheContexts = parent::getCacheContexts();
    $cacheContexts[] = 'route';
    return $cacheContexts;
  }

  /**
   * Create a link from a text and url.
   *
   * @param string text
   *   The link text.
   * @param \Drupal\Core\Url $url
   *
   * @return array|mixed[]
   *   The render array for a link.
   */
  public function createLink($text, Url $url) {
    $link = Link::fromTextAndUrl($text, $url)->toRenderable();
    $this->addLinkAttributes($link);
    return $link;
  }

  /**
   * Add link element attributes such as classes to the link.
   *
   * @param array $link
   */
  public function addLinkAttributes(array &$link) {
    $link['#options']['attributes']['class'][] = 'back-button';
  }

}
